AtomicBool

Type Alias AtomicBool 

1.0.0 · Source
pub type AtomicBool = Atomic<bool>;
A boolean type which can be safely shared between threads.

This type has the same size, alignment, and bit validity as a bool.

Note: This type is only available on platforms that support atomic loads and stores of u8.

Aliased Type

#[repr(C)]
pub struct AtomicBool { /* private fields */ }