AtomicU32

Type Alias AtomicU32 

1.34.0 · Source
pub type AtomicU32 = Atomic<u32>;
An integer type which can be safely shared between threads.

This type has the same size and bit validity as the underlying integer type, u32. However, the alignment of this type is always equal to its size, even on targets where u32 has a lesser alignment.

For more about the differences between atomic types and non-atomic types as well as information about the portability of this type, please see the module-level documentation.

Note: This type is only available on platforms that support atomic loads and stores of u32.

Aliased Type

#[repr(C)]
pub struct AtomicU32 { /* private fields */ }