pub type AtomicBool = Atomic<bool>;Expand description
A boolean type which can be safely shared between threads.
This type has the same size, alignment, and bit validity as a bool.
Note: This type is only available on platforms that support atomic
loads and stores of u8.
Aliased Type
#[repr(C)]pub struct AtomicBool { /* private fields */ }Trait Implementations
Sourceimpl<'de> Deserialize<'de> for AtomicBool
Available on no_target_has_atomic or target_has_atomic=8 only.
impl<'de> Deserialize<'de> for AtomicBool
Available on
no_target_has_atomic or target_has_atomic=8 only.Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more