pub type AtomicI32 = Atomic<i32>;Expand description
An integer type which can be safely shared between threads.
This type has the same
size and bit validity
as the underlying integer type, i32.
However, the alignment of this type is always equal to its size, even on targets where i32 has a lesser alignment.
For more about the differences between atomic types and non-atomic types as well as information about the portability of this type, please see the module-level documentation.
Note: This type is only available on platforms that support
atomic loads and stores of i32.
Aliased Type
#[repr(C)]pub struct AtomicI32 { /* private fields */ }Trait Implementations
Sourceimpl<'de> Deserialize<'de> for AtomicI32
Available on no_target_has_atomic or target_has_atomic=32 only.
impl<'de> Deserialize<'de> for AtomicI32
Available on
no_target_has_atomic or target_has_atomic=32 only.Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more